==> alibabacloud_iot20180120-0.3.0.tar.gz: alibabacloud_iot20180120-0.3.0/ChangeLog.md <==
2023-01-03 Version: 3.0.15
- Pub Support MessageExpiryInterval and Retained.
- Rrpc Support ContentType.
- BatchImportVehicleDevice batch create device by jt808 protocol.
- BatchCheckVehicleDevice batch check device by jt808 protocol.
- QueryVehicleDevice query jt808 device information.

2022-12-02 Version: 3.0.14
- Pub Support PayloadFormatIndicator and ContentType.

2022-12-01 Version: 3.0.13
- Iot_20180120 Old sdk.


2022-10-27 Version: 3.0.12
- Iot_20180120 TeaDSL sdk.

2022-09-16 Version: 3.0.11
- Iot_20180120 TeaDSL SDK.

2022-09-06 Version: 3.0.10
- Iot_20180120 TeaDSL SDK.

2022-07-21 Version: 3.0.9
- Add DOP apiSource add data api.

2022-07-18 Version: 3.0.8
- Iot_20180120 TeaDSL sdk.

2022-07-11 Version: 3.0.7
- Add new api for rule.

2022-06-20 Version: 3.0.6
- Support Easy Connect New API.

2022-05-06 Version: 3.0.5
- Iot_20180120 TeaDSL sdk.

2022-05-06 Version: 3.0.4
- Iot_20180120 TeaDSL sdk.

2022-03-03 Version: 3.0.3
- Iot_20180120 TeaDSL sdk.

2022-02-18 Version: 3.0.2
- Add DOP apiSource add data api.

2022-02-11 Version: 3.0.1
- Add OTA API, including ReupgradeOTATask.


2022-01-06 Version: 3.0.0
- Iot_20180120 TeaDSL sdk.

2021-09-22 Version: 2.4.0
- Add DOP apiSource add data api.

2021-09-08 Version: 2.3.0
- Add DOP apiSource add data api.

2021-09-08 Version: 0.2.0
- Generated python 2018-01-20 for Iot.

2021-05-02 Version: 2.2.2
- Generated python 2018-01-20 for Iot.

2021-04-27 Version: 2.2.1
- Update AMP API.

2021-03-10 Version: 0.1.0
- AMP Version Change.

2021-03-09 Version: 2.1.0
- Generated python 2018-01-20 for Iot.

2021-02-03 Version: 2.0.0
- Support TeaDSL.
- Fix dotnet SDK concurrency issue.

2021-01-10 Version: 1.0.1
- AMP Version Change.

2021-01-10 Version: 1.0.0
- Generated python 2018-01-20 for Iot.

==> alibabacloud_iot20180120-3.1.1.tar.gz: alibabacloud_iot20180120-3.1.1/ChangeLog.md <==
2023-03-02 Version: 3.1.0
- Add a API QueryDeviceProvisioning to support query provisioning info for device.

2023-02-10 Version: 3.0.16
- Support broadcast for FengTian.

2023-01-13 Version: 0.3.0
- Add ClearDeviceDesiredProperty open api.

2023-01-03 Version: 3.0.15
- Pub Support MessageExpiryInterval and Retained.
- Rrpc Support ContentType.
- BatchImportVehicleDevice batch create device by jt808 protocol.
- BatchCheckVehicleDevice batch check device by jt808 protocol.
- QueryVehicleDevice query jt808 device information.

2022-12-02 Version: 3.0.14
- Pub Support PayloadFormatIndicator and ContentType.

2022-12-01 Version: 3.0.13
- Iot_20180120 Old sdk.


2022-10-27 Version: 3.0.12
- Iot_20180120 TeaDSL sdk.

2022-09-16 Version: 3.0.11
- Iot_20180120 TeaDSL SDK.

2022-09-06 Version: 3.0.10
- Iot_20180120 TeaDSL SDK.

2022-07-21 Version: 3.0.9
- Add DOP apiSource add data api.

2022-07-18 Version: 3.0.8
- Iot_20180120 TeaDSL sdk.

2022-07-11 Version: 3.0.7
- Add new api for rule.

2022-06-20 Version: 3.0.6
- Support Easy Connect New API.

2022-05-06 Version: 3.0.5
- Iot_20180120 TeaDSL sdk.

2022-05-06 Version: 3.0.4
- Iot_20180120 TeaDSL sdk.

2022-03-03 Version: 3.0.3
- Iot_20180120 TeaDSL sdk.

2022-02-18 Version: 3.0.2
- Add DOP apiSource add data api.

2022-02-11 Version: 3.0.1
- Add OTA API, including ReupgradeOTATask.


2022-01-06 Version: 3.0.0
- Iot_20180120 TeaDSL sdk.

2021-09-22 Version: 2.4.0
- Add DOP apiSource add data api.

2021-09-08 Version: 2.3.0
- Add DOP apiSource add data api.

2021-09-08 Version: 0.2.0
- Generated python 2018-01-20 for Iot.

2021-05-02 Version: 2.2.2
- Generated python 2018-01-20 for Iot.

2021-04-27 Version: 2.2.1
- Update AMP API.

2021-03-10 Version: 0.1.0
- AMP Version Change.

2021-03-09 Version: 2.1.0
- Generated python 2018-01-20 for Iot.

2021-02-03 Version: 2.0.0
- Support TeaDSL.
- Fix dotnet SDK concurrency issue.

2021-01-10 Version: 1.0.1
- AMP Version Change.

2021-01-10 Version: 1.0.0
- Generated python 2018-01-20 for Iot.
